
.. highlight:: shell

============
Requirements
============


Yason is intended to be used as a part of JupyterLab deployment on Kubernetes that also has Argo workflows and access to S3 bucket (in my case S3 bucket is provided by Rook/Ceph) deployed on the same cluster.
